from setuptools import setup,find_packages

setup(
	name = "TeleAuto",
	version = "0.0.2",
	keywords = [],
	description = "tele's auto",
	long_description = "tele's auto",
	license = "MIT",
	url = "https://github.com/hikkki/py-try",
	author = "yxq",
	author_email = "yunyxq@163.com",
	#packages = find_packages(),
	packages = ['cases'],
	include_package_data = True,
	platforms = "any",
	install_requires = []
)